# Plan van aanpak

## The temperature of some fridges is checked daily

This risk is not present in your organisation, but since the sector organisation considers this one of the top 5 most critical risks it must be included in this report.

The temperature in a fridge is critical to storing food. If the temperature is too high or fluctuates too much food can start rotting quickly.

This is a
.

Select a standard solution. The main fields of this measure will be populated with the chosen solution.

1. Standard solution bla

   This is the text for action plan

   This is the text for prevention plan

   This is the text for requirements

2. Lorem ipsum dolor sit amet consectetuerLorem ipsum dolor sit amet consectetuerLorem ipsum dolor sit amet consectetuerLorem ipsum dolor sit amet consectetuerLorem ipsum dolor sit amet consectetuer

   This is the text for action plan

   This is the text for prevention plan

   This is the text for requirements

3. Tremendae

   This is the text for action plan

   This is the text for prevention plan

   This is the text for requirements

#### Legal and policy references

The requirements for fridges are defined in section 13.1 section a of the health code.

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Lorem | Ipsum Dolor | Sit